@@ -92,4 +92,4 @@ class print_dbg():
         super(print_dbg, self).__str__()
 
     def print_dbg(cls, text, module):
-        print(text) if dbg.get_module(module) else None
+        print('dbg => ' + text) if dbg.get_module(module) else None
